@@ -1,12 +1,12 @@
 package Text::Fragment;
 
-our $DATE = '2014-11-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Data::Clone;
 
@@ -654,7 +654,7 @@ Text::Fragment - Manipulate fragments in text
 
 =head1 VERSION
 
-This document describes version 0.06 of Text::Fragment (from Perl distribution Text-Fragment), released on 2014-11-17.
+This document describes version 0.07 of Text::Fragment (from Perl distribution Text-Fragment), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -710,9 +710,37 @@ To set fragment attributes:
 
  $res = se_fragment_attrs(text=>$text, id=>'bar', attrs=>{name=>'val', ...});
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Text-Fragment>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Text-Fragment>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Fragment>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 DESCRIPTION
 
 
+{en_US 
 A fragment is a single line or a group of lines (called payload) with a metadata
 encoded in the comment that is put adjacent to it (for a single line fragment)
 or enclosing it (for a multiline fragment). Fragments are usually used in
@@ -766,19 +794,23 @@ Another example (using C<ini>-style comment):
  allow_url_fopen=0
  ; END FRAGMENT
 
+}
+
 =head1 FUNCTIONS
 
 
 =head2 delete_fragment(%args) -> [status, msg, result, meta]
 
-Delete fragment in text.
+{en_US Delete fragment in text}.
 
+{en_US 
 If there are multiple occurences of fragment (which is considered an abnormal
 condition), all occurences will be deleted.
 
 Newline deletion behaviour: if fragment at the bottom of text does not end with
 newline (which is considered bad style), the text after the fragment is deleted
 will also not end with newline.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -786,24 +818,22 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-Comment style.
+{en_US Comment style}.
 
 =item * B<id>* => I<str>
 
-Fragment ID.
+{en_US Fragment ID}.
 
-=item * B<label> => I<code|str> (default: "FRAGMENT")
+=item * B<label> => I<str|code> (default: "FRAGMENT")
 
-Comment label.
+{en_US Comment label}.
 
 =item * B<text>* => I<str>
 
-The text to delete fragment from.
+{en_US The text to delete fragment from}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -813,24 +843,29 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-A hash of result (hash)
+Return value: {en_US A hash of result} (hash)
 
+
+{en_US 
 Will return status 200 if operation is successful and text is deleted. The
-result is a hash with the following keys: `text` will contain the new text,
-`orig_payload` will contain the original fragment payload before being deleted,
-`orig_fragment` will contain the original fragment. If there are multiple
+result is a hash with the following keys: C<text> will contain the new text,
+C<orig_payload> will contain the original fragment payload before being deleted,
+C<orig_fragment> will contain the original fragment. If there are multiple
 occurences (which is considered an abnormal condition), only the last deleted
-fragment will be returned in `orig_payload` and `orig_fragment`.
+fragment will be returned in C<orig_payload> and C<orig_fragment>.
 
 Will return status 304 if nothing is changed (i.e. when the fragment that needs
 to be deleted already does not exist in the text).
+}
 
 
 =head2 get_fragment(%args) -> [status, msg, result, meta]
 
-Get fragment with a certain ID in text.
+{en_US Get fragment with a certain ID in text}.
 
+{en_US 
 If there are multiple occurences of the fragment with the same ID ,
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -838,24 +873,22 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-Comment style.
+{en_US Comment style}.
 
 =item * B<id>* => I<str>
 
-Fragment ID.
+{en_US Fragment ID}.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-Comment label.
+{en_US Comment label}.
 
 =item * B<text>* => I<str>
 
-The text which contain fragments.
+{en_US The text which contain fragments}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -865,23 +898,28 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Fragment (array)
+Return value: {en_US Fragment} (array)
 
+
+{en_US 
 Will return status 200 if fragment is found. Result will be a hash with the
-following keys: `raw` (string), `payload` (string), `attrs` (hash), `id`
+following keys: C<raw> (string), C<payload> (string), C<attrs> (hash), C<id>
 (string, can also be found in attributes).
 
 Return 404 if fragment is not found.
+}
 
 
 =head2 insert_fragment(%args) -> [status, msg, result, meta]
 
-Insert or replace a fragment in text.
+{en_US Insert or replace a fragment in text}.
 
+{en_US 
 Newline insertion behaviour: if fragment is inserted at the bottom and text does
 not end with newline (which is considered bad style), the inserted fragment will
 also not end with newline. Except when original text is an empty string, in
 which case an ending newline will still be added.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -891,51 +929,53 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-Comment style.
+{en_US Comment style}.
 
 =item * B<good_pattern> => I<str>
 
-Regex pattern which if found means fragment need not be inserted.
+{en_US Regex pattern which if found means fragment need not be inserted}.
 
 =item * B<id>* => I<str>
 
-Fragment ID.
+{en_US Fragment ID}.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-Comment label.
+{en_US Comment label}.
 
 =item * B<payload>* => I<str>
 
-Fragment content.
+{en_US Fragment content}.
 
 =item * B<replace_pattern> => I<str>
 
-Regex pattern which if found will be used for placement of fragment.
+{en_US Regex pattern which if found will be used for placement of fragment}.
 
+{en_US 
 If fragment needs to be inserted into file, then if C<replace_pattern> is defined
 then it will be searched. If found, fragment will be placed to replace the
 pattern. Otherwise, fragment will be inserted at the end (or beginning, see
 C<top_style>) of file.
+}
 
 =item * B<text>* => I<str>
 
-The text to insert fragment into.
+{en_US The text to insert fragment into}.
 
 =item * B<top_style> => I<bool> (default: 0)
 
-Whether to append fragment at beginning of file instead of at the end.
+{en_US Whether to append fragment at beginning of file instead of at the end}.
 
+{en_US 
 Default is false, which means to append at the end of file.
 
 Note that this only has effect if C<replace_pattern> is not defined or replace
 pattern is not found in file. Otherwise, fragment will be inserted to replace
 the pattern.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -945,22 +985,24 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-A hash of result (hash)
+Return value: {en_US A hash of result} (hash)
 
+
+{en_US 
 Will return status 200 if operation is successful and text is changed. The
-result is a hash with the following keys: `text` will contain the new text,
-`orig_payload` will contain the original payload before being removed/replaced,
-`orig_fragment` will contain the original fragment (or the text that matches
-`replace_pattern`).
-
+result is a hash with the following keys: C<text> will contain the new text,
+C<orig_payload> will contain the original payload before being removed/replaced,
+C<orig_fragment> will contain the original fragment (or the text that matches
+C<replace_pattern>).
 
 Will return status 304 if nothing is changed (i.e. if fragment with the
 same payload that needs to be inserted already exists in the text).
+}
 
 
 =head2 list_fragments(%args) -> [status, msg, result, meta]
 
-List fragments in text.
+{en_US List fragments in text}.
 
 Arguments ('*' denotes required arguments):
 
@@ -968,20 +1010,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-Comment style.
+{en_US Comment style}.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-Comment label.
+{en_US Comment label}.
 
 =item * B<text>* => I<str>
 
-The text which contain fragments.
+{en_US The text which contain fragments}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -991,19 +1031,24 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-List of fragments (array)
+Return value: {en_US List of fragments} (array)
 
+
+{en_US 
 Will return status 200 if operation is successful. Result will be an array of
-fragments, where each fragment is a hash containing these keys: `raw` (string),
-`payload` (string), `attrs` (hash), `id` (string, can also be found in
+fragments, where each fragment is a hash containing these keys: C<raw> (string),
+C<payload> (string), C<attrs> (hash), C<id> (string, can also be found in
 attributes).
+}
 
 
 =head2 set_fragment_attrs(%args) -> [status, msg, result, meta]
 
-Set/unset attributes of a fragment.
+{en_US Set/unset attributes of a fragment}.
 
+{en_US 
 If there are multiple occurences of the fragment with the same ID ,
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1011,28 +1056,28 @@ Arguments ('*' denotes required arguments):
 
 =item * B<attrs>* => I<hash>
 
+{en_US 
 To delete an attribute in the fragment, you can set the value to undef.
+}
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-Comment style.
+{en_US Comment style}.
 
 =item * B<id>* => I<str>
 
-Fragment ID.
+{en_US Fragment ID}.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-Comment label.
+{en_US Comment label}.
 
 =item * B<text>* => I<str>
 
-The text which contain fragments.
+{en_US The text which contain fragments}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -1042,39 +1087,15 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-New text and other data (array)
+Return value: {en_US New text and other data} (array)
 
+
+{en_US 
 Will return status 200 if fragment is found. Result will be a hash containing
-these keys: `text` (string, the modified text), `orig_attrs` (hash, the old
+these keys: C<text> (string, the modified text), C<orig_attrs> (hash, the old
 attributes before being modified).
 
 Return 404 if fragment is not found.
-
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Text-Fragment>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Text-Fragment>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Fragment>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+}
 
 =cut
